# Generated by Django 2.2.5 on 2019-09-02 22:35

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0041_messages_guid'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='state',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='tracker.Messages_state'),
        ),
    ]
