# Generated by Django 2.2.4 on 2019-08-25 21:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0065_auto_20190825_2037'),
    ]

    operations = [
        migrations.AddField(
            model_name='day_types',
            name='isholiday',
            field=models.BooleanField(default=False),
        ),
    ]
