# Generated by Django 2.2.1 on 2019-05-16 06:48

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0019_messages_view'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='checksum',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Checksum MD5'),
        ),
    ]
