# Generated by Django 2.2.5 on 2019-09-08 15:34

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('twits', '0009_auto_20190905_1810'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='chat_user_user',
            options={'verbose_name': 'Чаты личной переписки'},
        ),
        migrations.AlterModelOptions(
            name='chats',
            options={'verbose_name': 'Групповые чаты'},
        ),
        migrations.AddField(
            model_name='chat_user_user',
            name='props',
            field=bitfield.models.BitField((('compulsory_reading', 'Обязательное прочтение'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='chats',
            name='props',
            field=bitfield.models.BitField((('compulsory_reading', 'Обязательное прочтение'),), db_index=True, default=0),
        ),
    ]
