# Generated by Django 2.2.6 on 2019-10-09 14:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0066_auto_20190920_1118'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='messages',
            unique_together=set(),
        ),
    ]
