# Generated by Django 2.2.4 on 2019-08-26 06:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0066_day_types_isholiday'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shift_day_relax',
            options={'ordering': ['relaxorder', 'shiftday'], 'verbose_name': 'Запланированные перекуры и отдыхи'},
        ),
        migrations.AddField(
            model_name='shift_day_relax',
            name='relaxorder',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterUniqueTogether(
            name='shift_day_relax',
            unique_together={('relaxorder', 'shiftday')},
        ),
    ]
