# Generated by Django 2.2.5 on 2019-09-20 11:18

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0065_auto_20190916_1759'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages_theme',
            name='code',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, unique=True),
        ),
    ]
