# Generated by Django 3.0.3 on 2020-02-08 11:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0012_auto_20191116_1827'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='visitor',
            constraint=models.UniqueConstraint(fields=('username', 'ip_address'), name='Visitor_unique_1'),
        ),
        migrations.AddConstraint(
            model_name='visitor',
            constraint=models.UniqueConstraint(condition=models.Q(username=None), fields=('ip_address',), name='Visitor_unique_2'),
        ),
    ]
